==> knative-model-5.10.1-sources.jar: io/fabric8/knative/eventing/v1beta1/EventTypeSpecBuilder.java <==
package io.fabric8.knative.eventing.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class EventTypeSpecBuilder extends io.fabric8.knative.eventing.v1beta1.EventTypeSpecFluentImpl<io.fabric8.knative.eventing.v1beta1.EventTypeSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.knative.eventing.v1beta1.EventTypeSpec,io.fabric8.knative.eventing.v1beta1.EventTypeSpecBuilder>{
  public EventTypeSpecBuilder() {
    this(false);
  }
  public EventTypeSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new EventTypeSpec(), validationEnabled);
  }
  public EventTypeSpecBuilder(io.fabric8.knative.eventing.v1beta1.EventTypeSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public EventTypeSpecBuilder(io.fabric8.knative.eventing.v1beta1.EventTypeSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new EventTypeSpec(), validationEnabled);
  }
  public EventTypeSpecBuilder(io.fabric8.knative.eventing.v1beta1.EventTypeSpecFluent<?> fluent,io.fabric8.knative.eventing.v1beta1.EventTypeSpec instance) {
    this(fluent, instance, false);
  }
  public EventTypeSpecBuilder(io.fabric8.knative.eventing.v1beta1.EventTypeSpecFluent<?> fluent,io.fabric8.knative.eventing.v1beta1.EventTypeSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBroker(instance.getBroker()); 
    fluent.withDescription(instance.getDescription()); 
    fluent.withSchema(instance.getSchema()); 
    fluent.withSchemaData(instance.getSchemaData()); 
    fluent.withSource(instance.getSource()); 
    fluent.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  public EventTypeSpecBuilder(io.fabric8.knative.eventing.v1beta1.EventTypeSpec instance) {
    this(instance,false);
  }
  public EventTypeSpecBuilder(io.fabric8.knative.eventing.v1beta1.EventTypeSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withBroker(instance.getBroker()); 
    this.withDescription(instance.getDescription()); 
    this.withSchema(instance.getSchema()); 
    this.withSchemaData(instance.getSchemaData()); 
    this.withSource(instance.getSource()); 
    this.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.knative.eventing.v1beta1.EventTypeSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.knative.eventing.v1beta1.EventTypeSpec build() {
    EventTypeSpec buildable = new EventTypeSpec(fluent.getBroker(),fluent.getDescription(),fluent.getSchema(),fluent.getSchemaData(),fluent.getSource(),fluent.getType());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EventTypeSpecBuilder that = (EventTypeSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> knative-model-6.6.2-sources.jar: io/fabric8/knative/eventing/v1beta1/EventTypeSpecBuilder.java <==
package io.fabric8.knative.eventing.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EventTypeSpecBuilder extends EventTypeSpecFluentImpl<EventTypeSpecBuilder> implements VisitableBuilder<EventTypeSpec,EventTypeSpecBuilder>{
  public EventTypeSpecBuilder() {
    this(false);
  }
  public EventTypeSpecBuilder(Boolean validationEnabled) {
    this(new EventTypeSpec(), validationEnabled);
  }
  public EventTypeSpecBuilder(EventTypeSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public EventTypeSpecBuilder(EventTypeSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EventTypeSpec(), validationEnabled);
  }
  public EventTypeSpecBuilder(EventTypeSpecFluent<?> fluent,EventTypeSpec instance) {
    this(fluent, instance, false);
  }
  public EventTypeSpecBuilder(EventTypeSpecFluent<?> fluent,EventTypeSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBroker(instance.getBroker()); 
    fluent.withDescription(instance.getDescription()); 
    fluent.withSchema(instance.getSchema()); 
    fluent.withSchemaData(instance.getSchemaData()); 
    fluent.withSource(instance.getSource()); 
    fluent.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  public EventTypeSpecBuilder(EventTypeSpec instance) {
    this(instance,false);
  }
  public EventTypeSpecBuilder(EventTypeSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withBroker(instance.getBroker()); 
    this.withDescription(instance.getDescription()); 
    this.withSchema(instance.getSchema()); 
    this.withSchemaData(instance.getSchemaData()); 
    this.withSource(instance.getSource()); 
    this.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  EventTypeSpecFluent<?> fluent;
  Boolean validationEnabled;
  public EventTypeSpec build() {
    EventTypeSpec buildable = new EventTypeSpec(fluent.getBroker(),fluent.getDescription(),fluent.getSchema(),fluent.getSchemaData(),fluent.getSource(),fluent.getType());
    return buildable;
  }
  
}
